@@ -1,7 +1,7 @@
 package Perinci::CmdLine::Inline;
 
-our $DATE = '2015-07-30'; # DATE
-our $VERSION = '0.17'; # VERSION
+our $DATE = '2015-07-31'; # DATE
+our $VERSION = '0.18'; # VERSION
 
 use 5.010001;
 use strict;
@@ -836,7 +836,7 @@ Perinci::CmdLine::Inline - Generate inline Perinci::CmdLine CLI script
 
 =head1 VERSION
 
-This document describes version 0.17 of Perinci::CmdLine::Inline (from Perl distribution Perinci-CmdLine-Inline), released on 2015-07-30.
+This document describes version 0.18 of Perinci::CmdLine::Inline (from Perl distribution Perinci-CmdLine-Inline), released on 2015-07-31.
 
 =head1 SYNOPSIS
 
@@ -862,23 +862,23 @@ B<EARLY DEVELOPMENT.>
 
 Sample startup overhead benchmark vs Perinci::CmdLine::Lite:
 
-                                   Rate  run 1 (lite) run --version (lite)    -c (lite) run 1 (inline) -c (inline) run --version (inline)   perl
- run 1 (lite)           13.569+-0.013/s            --               -61.0%       -82.0%         -89.1%      -90.6%                 -91.2% -97.1%
- run --version (lite)   34.785+-0.052/s 156.36+-0.45%                   --       -54.0%         -72.1%      -75.9%                 -77.6% -92.6%
- -c (lite)                75.56+-0.19/s   456.9+-1.5%        117.23+-0.64%           --         -39.4%      -47.6%                 -51.2% -83.8%
- run 1 (inline)          124.61+-0.34/s   818.3+-2.6%          258.2+-1.1% 64.91+-0.62%             --      -13.6%                 -19.6% -73.3%
- -c (inline)               144.3+-3.1/s      963+-23%            314.7+-9%   90.9+-4.2%     15.8+-2.5%          --                  -6.9% -69.1%
- run --version (inline)    154.9+-1.1/s  1041.9+-8.3%          345.4+-3.3%  105.1+-1.6%   24.35+-0.95%   7.4+-2.5%                     -- -66.9%
- perl                      467.4+-3.2/s     3345+-24%         1243.8+-9.3%  518.6+-4.5%    275.1+-2.7%   224+-7.4%              201.7+-3%     --
+                                  Rate run 1 (lite) run --version (lite)   -c (lite) run 1 (inline) run --version (inline) -c (inline)   perl
+ run 1 (lite)           13.502+-0.02/s           --               -60.2%      -81.8%         -88.2%                 -91.7%      -93.6% -97.4%
+ run --version (lite)    33.93+-0.18/s  151.3+-1.4%                   --      -54.3%         -70.3%                 -79.0%      -83.9% -93.4%
+ -c (lite)               74.33+-0.43/s  450.5+-3.3%          119.1+-1.7%          --         -34.9%                 -54.1%      -64.6% -85.4%
+ run 1 (inline)         114.17+-0.51/s    745.6+-4%          236.5+-2.3%  53.6+-1.1%             --                 -29.4%      -45.7% -77.6%
+ run --version (inline)   161.8+-1.1/s 1098.4+-8.3%          376.9+-4.1% 117.7+-1.9%     41.7+-1.1%                     --      -23.0% -68.3%
+ -c (inline)              210.2+-1.9/s    1457+-15%          519.6+-6.6% 182.9+-3.1%     84.2+-1.9%             29.9+-1.5%          -- -58.8%
+ perl                     510.8+-1.7/s    3683+-14%         1405.4+-9.5% 587.2+-4.6%    347.4+-2.5%            215.7+-2.4% 142.9+-2.4%     --
  
  Average times:
-   perl                  :     2.1395ms
-   run --version (inline):     6.4558ms
-   -c (inline)           :     6.9300ms
-   run 1 (inline)        :     8.0250ms
-   -c (lite)             :    13.2345ms
-   run --version (lite)  :    28.7480ms
-   run 1 (lite)          :    73.6974ms
+   perl                  :     1.9577ms
+   -c (inline)           :     4.7574ms
+   run --version (inline):     6.1805ms
+   run 1 (inline)        :     8.7589ms
+   -c (lite)             :    13.4535ms
+   run --version (lite)  :    29.4724ms
+   run 1 (lite)          :    74.0631ms
 
 =head1 FUNCTIONS
 
